/* 
Descriptives
Living and Minimum Wages in Jordan and Tunisia
Created: October 5 2021
Updated: 2024.04.19
Last updated by: Caroline Krafft

Version 9

*/

set scheme s1color

*Analysis data
use "Wages JO TN analysis data.dta", clear

**************
***Figure 2
***************

gen mean_wg=.

foreach num of numlist 2010 2014 2016 {
	sum mnthwg [aw=expan_ind] if round==`num'
	replace mean_wg=`r(mean)' if round==`num'
	}
bysort round: sum mean_wg

*Using main wage
*2010: 150 
di 150/445.8476     

*2016: 190 
di 190/517.8236  

*2014: 301
di 301/511.0712 
	
**************
***% earn
***************

bysort round: sum earn_min earn_PL earn_med earn_liv [aw=expan_indiv]

capture erase "Graphs and Tables/Pct wages.xls"

foreach var of varlist earn_min earn_PL earn_med earn_liv {

gen pct_`var'=`var'*100

tabout nationality_cl agegrp2 sex marital educ1 urban region /* worker */ ///
usocp1d ussocinsp uscontrp usirreg usestblp edreq skilreq math fitness computer literacy /* job */  ///
usecac1d usfirm_size usfmwrkprcnt uspublic round /* firm*/ [aw=expan_indiv] using "Graphs and Tables/Pct wages.xls", f(0) cells(mean pct_`var') sum append ptotal(single) 

}

tabout nationality_cl agegrp2 sex marital educ1 urban region /* worker */ ///
usocp1d ussocinsp uscontrp usirreg usestblp edreq skilreq math fitness computer literacy /* job */  ///
usecac1d usfirm_size usfmwrkprcnt uspublic round /* firm*/ if earn_min!=. using "Graphs and Tables/Pct wages.xls", f(0) cells(freq) append ptotal(single)


*********
***CDFs
*********
*Total and by sector

expand 2
bysort indid: gen sector=3 if _n==2
replace sector=1 if uspublic==1 & sector==.
replace sector=2 if uspublic==0 & sector==.

la def Lsector 1 "Public" 2 "Private" 3 "Total"

*1. Monthly total primary job wages
cumul mnthwg if mnthwg>0 & mnthwg<. [aw=expan_indiv], gen(c2_mnthwg) equal by(round sector)

*stack c2_hhwg hhwg, into(c temp) wide clear
gen cutoff=.

foreach round of numlist 2010 2014 2016 {
sum mnthwg if round==`round', detail
replace cutoff=r(p95) if round==`round'
}

*Jordan 2016
graph twoway scatter c2_mnthwg mnthwg if mnthwg<cutoff & round==2016 & sector==3, sort c(l)mcolor(black) lcolor(black) msize(*.5) msymbol(o) ///
 || scatter c2_mnthwg mnthwg if mnthwg<cutoff & round==2016 & sector==2, sort c(l) mcolor(khaki) lcolor(khaki) msize(*.5) msymbol(d) /// 
 || scatter c2_mnthwg mnthwg if mnthwg<cutoff & round==2016 & sector==1, sort c(l) mcolor(midblue) lcolor(midblue) msize(*.5) msymbol(T) /// 
 ytitle("Share of monthly wages") ///
 xtitle("Monthly wages (in Jordanian Dinar)") ///
 plotregion(margin(zero))  title("Jordan 2016") ///
  xline(150 190 267 330 502) xlabel(0 150 "Non-Jor. (2016) - 150" 190 "Jor. (2016) - 190" 267 "Pov. - 267" 330 "Median - 330" 400 502 "Living - 502" 800, angle(65) labsize(small)) legend(label(1 "Total") label(2 "Private") label(3 "Public") row(1) span)
  

graph save "Graphs and Tables/cdf_2016.gph", replace
graph export "Graphs and Tables/cdf_2016.tif", replace width(1500)


*Jordan 2010
graph twoway scatter c2_mnthwg mnthwg if mnthwg<cutoff & round==2010 & sector==3, sort c(l)mcolor(black) lcolor(black) msize(*.5) msymbol(o) ///
 || scatter c2_mnthwg mnthwg if mnthwg<cutoff & round==2010 & sector==2, sort c(l) mcolor(khaki) lcolor(khaki) msize(*.5) msymbol(d) /// 
 || scatter c2_mnthwg mnthwg if mnthwg<cutoff & round==2010 & sector==1, sort c(l) mcolor(midblue) lcolor(midblue) msize(*.5) msymbol(T) /// 
 ytitle("Share of monthly wages") ///
 xtitle("Monthly wages (in Jordanian Dinar)") ///
 plotregion(margin(zero))  title("Jordan 2010") ///
  xline(150 231 264 435) xlabel(0 150 "Jor. (2010) - 150" 231 "Pov. - 231" 264 "Median - 264" 400 435 "Living - 435" 800, angle(65) labsize(small)) legend(label(1 "Total") label(2 "Private") label(3 "Public") row(1) span)
  

graph save "Graphs and Tables/cdf_2010.gph", replace
graph export "Graphs and Tables/cdf_2010.tif", replace width(1500)

*Tunisia
graph twoway scatter c2_mnthwg mnthwg if mnthwg<cutoff & country==788 & sector==3, sort c(l)mcolor(black) lcolor(black) msize(*.5) msymbol(o) ///
 || scatter c2_mnthwg mnthwg if mnthwg<cutoff & country==788 & sector==2, sort c(l) mcolor(khaki) lcolor(khaki) msize(*.5) msymbol(d) /// 
 || scatter c2_mnthwg mnthwg if mnthwg<cutoff & country==788 & sector==1, sort c(l) mcolor(midblue) lcolor(midblue) msize(*.5) msymbol(T) /// 
 ytitle("Share of monthly wages") ///
 xtitle("Monthly wages (in Tunisian Dinar)") ///
 mcolor(midblue) ///
  lcolor(midblue) plotregion(margin(zero))  title("Tunisia") ///
  xline(266 300 330 348 420 634)  xlabel(266 "Ag. (2014) - 266" 300 "40h (2014) - 300" 330 "Pov. cities - 330" 348 "48h (2014) - 348" 400 420 "Median - 420" 600 634 "Liv. cities - 634" 800, angle(65) labsize(small))  legend(label(1 "Total") label(2 "Private") label(3 "Public") row(1) span)
  
graph save "Graphs and Tables/cdf_788.gph", replace
graph export "Graphs and Tables/cdf_788.tif", replace width(1500)



grc1leg "Graphs and Tables/cdf_2010.gph" "Graphs and Tables/cdf_2016.gph" "Graphs and Tables/cdf_788.gph", col(1) 

graph display, ysize(20) xsize(12)

graph save "Graphs and Tables/cdf.gph", replace
graph export "Graphs and Tables/cdf.tif", replace width(1500)


*************
*Appendix figure
*************


*Analysis data
use "Wages JO TN analysis data.dta", clear

gen cutoff=.

foreach round of numlist 2010 2014 2016 {
sum mnthwg if round==`round', detail
replace cutoff=r(p95) if round==`round'
}


cumul mnthwg if mnthwg>0 & mnthwg<. [aw=expan_indiv], gen(c2_mnthwg) equal by(round)
cumul min_pub if min_pub>0 & min_pub<. [aw=expan_indiv], gen(c2_min_pub) equal by(round)
cumul min_priv_inf if min_priv_inf>0 & min_priv_inf<. [aw=expan_indiv], gen(c2_min_inf) equal by(round)
cumul min_priv_form if min_priv_form>0 & min_priv_form<. [aw=expan_indiv], gen(c2_min_form) equal by(round)


*Jordan 2016
graph twoway scatter c2_mnthwg mnthwg if mnthwg<cutoff & round==2016, sort c(l) mcolor(black) lcolor(black) msize(*.5) msymbol(T) ///
 || scatter c2_min_pub min_pub if min_pub<cutoff & round==2016, sort c(l) mcolor(khaki) lcolor(khaki) msize(*.5) msymbol(d) /// 
 || scatter c2_min_form min_priv_form if min_priv_form<cutoff & round==2016, sort c(l) mcolor(midblue) lcolor(midblue) msize(*.5) msymbol(o) /// 
 || scatter c2_min_inf min_priv_inf if min_priv_inf<cutoff & round==2016, sort c(l) mcolor(red) lcolor(red) msize(*.5) msymbol(x) /// 
 ytitle("Share of monthly wages") ///
 xtitle("Monthly wages (in Jordanian Dinar)") ///
 plotregion(margin(zero))  title("Jordan 2016") ///
  xline(150 190 267 330 502) xlabel(0 150 "Non-Jor. (2016) - 150" 190 "Jor. (2016) - 190" 267 "Pov. - 267" 330 "Median - 330" 400 502 "Living - 502" 800, angle(65) labsize(small)) legend(label(1 "Wages") label(2 "Res. wage - public") label(3 "Res. wage - priv. form.") label(4 "Res. wage - priv. inf.") row(2) span)
  

graph save "Graphs and Tables/cdf_res_2016.gph", replace
graph export "Graphs and Tables/cdf_res_2016.tif", replace width(1500)


*Tunisia
graph twoway scatter c2_mnthwg mnthwg if mnthwg<cutoff & round==2014, sort c(l) mcolor(black) lcolor(black) msize(*.5) msymbol(T) ///
 || scatter c2_min_pub min_pub if min_pub<cutoff & round==2014, sort c(l) mcolor(khaki) lcolor(khaki) msize(*.5) msymbol(d) /// 
 || scatter c2_min_form min_priv_form if min_priv_form<cutoff & round==2014, sort c(l) mcolor(midblue) lcolor(midblue) msize(*.5) msymbol(o) /// 
 || scatter c2_min_inf min_priv_inf if min_priv_inf<cutoff & round==2014, sort c(l) mcolor(red) lcolor(red) msize(*.5) msymbol(x) /// 
 ytitle("Share of monthly wages") ///
 xtitle("Monthly wages (in Tunisian Dinar)") ///
 plotregion(margin(zero))  title("Tunisia") ///
xline(266 300 330 348 420 634)  xlabel(266 "Ag. (2014) - 266" 300 "40h (2014) - 300" 330 "Pov. cities - 330" 348 "48h (2014) - 348" 400 420 "Median - 420" 600 634 "Liv. cities - 634" 800, angle(65) labsize(small))  legend(label(1 "Wages") label(2 "Res. wage - public") label(3 "Res. wage - priv. form.") label(4 "Res. wage - priv. inf.") row(2) span)
  
  
graph save "Graphs and Tables/cdf_res_788.gph", replace
graph export "Graphs and Tables/cdf_res_ 788.tif", replace width(1500)


grc1leg "Graphs and Tables/cdf_res_2016.gph" "Graphs and Tables/cdf_res_788.gph", col(1) 

graph display, ysize(20) xsize(15)

graph save "Graphs and Tables/cdf_res.gph", replace
graph export "Graphs and Tables/cdf_res.tif", replace width(1500)


*************
*Appendix table 
*************

*Analysis data
use "Wages JO TN analysis data.dta", clear

capture erase "Graphs and Tables/Pct wages unemp.xls"

foreach var of varlist un_earn* earn_min earn_PL earn_med earn_liv {

gen pct_`var'=`var'*100

tabout round if round!=2010 [aw=expan_indiv] using "Graphs and Tables/Pct wages res.xls", f(0) cells(mean pct_`var') sum append ptotal(none) 

}

*Combined
replace un_earn_min=earn_min if usemp1==1 
replace un_earn_PL=earn_PL if usemp1==1 
replace un_earn_med=earn_med if usemp1==1 
replace un_earn_liv=earn_liv if usemp1==1 


foreach var of varlist un_earn* {

replace pct_`var'=`var'*100

tabout round if round!=2010 [aw=expan_indiv] using "Graphs and Tables/Pct wages res.xls", f(0) cells(mean pct_`var') sum append ptotal(none) 

}



