/* 
Data prep
Living and Minimum Wages in Jordan and Tunisia
Created: November 8 2021
Updated: 2024.01.01
Last updated by: Caroline Krafft

Version 12

*/


*Pulling from country data
*TLMPS
use "TLMPS 2014/TLMPS 2014 v2.1 all.dta", clear

clonevar uscontrdur=v643

clonevar literacy=v615_1
clonevar math=v615_2
clonevar fitness=v615_3
clonevar computer=v615_4

foreach var of varlist literacy math fitness computer {
	replace `var'=2 if `var'==98
}

clonevar other_socins=v633

replace indid="788"+indid

*Reservation wages
gen min_pub=v513
gen min_priv_form=v514
gen min_priv_inf=v515

keep indid uscontrdur literacy math fitness computer other_socins h118_h119 min_pub min_priv_form min_priv_inf

save "Eat/TLMPS prep.dta", replace

*JLMPS 2016
use "JLMPS 2016/JLMPS 2016 xs v1.1 pt 1.dta", clear

clonevar uscontrdur=q6146

clonevar literacy=q6116_1
clonevar math=q6116_2
clonevar fitness=q6116_3
clonevar computer=q6116_4

foreach var of varlist literacy math fitness computer {
	replace `var'=2 if `var'==98
}

clonevar other_socins=q6136

replace indid="400"+indid


*Reservation wages
gen min_pub=q5204 if q5204<9996
gen min_priv_form=q5205 if q5205<9996
gen min_priv_inf=q5206 if q5206<9996

keep indid uscontrdur literacy math fitness computer other_socins visit_date min_pub min_priv_form min_priv_inf

save "Eat/JLMPS prep.dta", replace

*JLMPS 2010
use "JLMPS 2010/JLMPS 2010 v3.4.dta", clear

clonevar uscontrdur=q626

/*JLMPS 2010 lacks skills variables, other workers have social insurance*/

replace indid="40000"+indid

keep indid uscontrdur /*literacy math fitness computer other_socins */ visit_m

save "Eat/JLMPS 2010 prep.dta", replace

*Harmonized data
use "ILMPS v4.0/Integrated LMPs v4.0.dta", clear

*Samples - Jordan 2010, 2016 and Tunisia 2014
keep if round==2014 | round==2010 | round==2016

merge 1:1 indid using "Eat/TLMPS prep.dta"
tabu round _merge
drop _merge

merge 1:1 indid using "Eat/JLMPS prep.dta", update
tabu round _merge
drop _merge

merge 1:1 indid using "Eat/JLMPS 2010 prep.dta", update
tabu round _merge
drop _merge

*Stat: Ns
gen wage_worker=usempstp==1
tabu wage_worker round if mnthwg!=.

tabu round
tabu round if pn==1

*% of HH with wage earners
*% employed
clonevar all_usemp1=usemp1
replace all_usemp1=0 if age<6
tabu all_usemp1 round [aw=expan_indiv], col nofreq

clonevar all_weight=expan_indiv
replace all_weight=expan_roster if age<6

*% of employed wage workers
tabu usempstp round if usemp1==1 [aw=all_weight], col nofreq

egen hh_usemp1=max(all_usemp1), by(hhid)
egen hh_usempstp=min(usempstp), by(hhid)

tabu hh_usemp1 round if pn==1 [aw=expan_hh], col nofreq
tabu hh_usempstp round if pn==1 [aw=expan_hh], col nofreq

*Age 15+
keep if age>=15

*Jordan 2010 firm size only if in establishment - making micro otherwise
replace usfirm_size=1 if usestblp==0 & round==2010
*Jordan 2010 firm size only if in private - making public large
replace usfirm_size=6 if ussectrp<=2 & round==2010

**********
*Outcomes
**********

*Footnote: basic vs. total
gen diff=ttmonwg3-basicwg3

tabu diff round [aw=expan_ind], col nofreq

replace diff=diff/basicwg3*100

bysort round: sum diff [aw=expan_ind], detail
bysort round: sum diff if diff!=0 [aw=expan_ind], detail



***Modify regular workers to be basic only
replace mnthwg=basicwg3/ttmonwg3*mnthwg if usirreg==0

****Minimum wage****
gen minimum=.

*********
*JO 2016
*********

*Jordan implemented Feb. 8 2017 but takes time to percolate through
*Domestic work and clothing not covered
*Jordan 2016 190 JD Jordanians
replace minimum=190 if nationality_cl==1 & (visit_date<=date("08feb2017","DMY")) & usecac1d_cl!=19 & (usecactp_nh<1311 | usecactp_nh>1520) & round==2016
*Jordan 2016 150 JD for non-Jordanians
replace minimum=150 if nationality_cl!=1 & (visit_date<=date("08feb2017","DMY")) & usecac1d_cl!=19 & (usecactp_nh<1311 | usecactp_nh>1520) & round==2016
*Jordan 2017 220 for Jordanians
replace minimum=220 if nationality_cl==1 & (visit_date>date("08feb2017","DMY")) & usecac1d_cl!=19 & (usecactp_nh<1311 | usecactp_nh>1520) & round==2016
*Jordan 2017 150 for non-Jordanians
replace minimum=150 if nationality_cl!=1 & (visit_date>date("08feb2017","DMY")) & usecac1d_cl!=19 & (usecactp_nh<1311 | usecactp_nh>1520) & round==2016
*Clothing (textiles) and domestic work
replace minimum=110 if (usecac1d_cl==19 | (usecactp_nh>=1311 & usecactp_nh<=1520)) & round==2016

*Unemployed 
*Jordan 2016 190 JD Jordanians
gen un_minimum=190 if nationality_cl==1 & (visit_date<=date("08feb2017","DMY")) & unemp1==1 & round==2016
*Jordan 2016 150 JD for non-Jordanians
replace un_minimum=150 if nationality_cl!=1 & (visit_date<=date("08feb2017","DMY")) & unemp1==1 & round==2016
*Jordan 2017 220 for Jordanians
replace un_minimum=220 if nationality_cl==1 & (visit_date>date("08feb2017","DMY")) & unemp1==1 & round==2016
*Jordan 2017 150 for non-Jordanians
replace un_minimum=150 if nationality_cl!=1 & (visit_date>date("08feb2017","DMY")) & unemp1==1 & round==2016



*Jordan 2010 150 JD Jordanians
replace minimum=150 if nationality_cl==1 & usecac1d!=19 & (usecactp<1311 | usecactp>1520) & round==2010
*Jordan 2010 none for non-Jordanians, missing
*Clothing (textiles) and domestic work - Jordanians only
replace minimum=110 if nationality_cl==1 & (usecac1d_cl==19 | (usecactp_nh>=1311 & usecactp_nh<=1520)) & round==2010


*Tunisia
*Less than 48 hours per week, non-ag (SMIG, 40h) - Start of 2014
replace minimum=300.671 if  country==788 & ushrswk1<48 & usecac1d!=0 & (h118_h119<=date("23jun2014","DMY") | h118_h119==.)
*Later 2014
replace minimum=275.591 if  country==788 & ushrswk1<48 & usecac1d!=0 & (h118_h119>date("23jun2014","DMY")) & h118_h119!=.

*48 or more hours per week, non-ag (SMIG, 48h) - Start of 2014
replace minimum=320 if  country==788 & ushrswk1>=48 & ushrswk1!=. & usecac1d!=0 & (h118_h119<=date("23jun2014","DMY") | h118_h119==.)
*Later 2014
replace minimum=348.096 if  country==788 & ushrswk1>=48 & ushrswk1!=. & usecac1d!=0 & (h118_h119>date("23jun2014","DMY")) & h118_h119!=.

*Agricultural minimum wage - Start of 2014
replace minimum=11.608*ushrs3mnth/ushrsday/3 if  country==788 & usecac1d==0 & (h118_h119<=date("23jun2014","DMY") | h118_h119==.)
*Later 2014
replace minimum=12.304*ushrs3mnth/ushrsday/3 if  country==788 & usecac1d==0 & (h118_h119>date("23jun2014","DMY")) & h118_h119!=.


*Unemployed, assuming minimum is SMIG, 40h
replace un_minimum=300.671 if  country==788 & unemp1==1 & (h118_h119<=date("23jun2014","DMY") | h118_h119==.)
*Later 2014
replace un_minimum=275.591 if  country==788 & unemp1==1 & (h118_h119>date("23jun2014","DMY")) & h118_h119!=.


****Earn a minimum wage****
gen earn_min=.
replace earn_min=1 if usempstp==1 & mnthwg>=minimum & mnthwg<.  & minimum!=.
replace earn_min=0 if usempstp==1 & mnthwg<minimum & mnthwg<. & minimum!=.

****Living wages****
*2020 adjusted for inflation (see Jordan and Tunisia CPI file)
*Tunisia use same ratio of poverty lines by location

/*Tunisia*/
gen liv_wage=695*0.725296038 if country==788 & cat_ville==3
replace liv_wage=695*0.725296038*101/89 if country==788 & cat_ville==2
replace liv_wage=695*0.725296038*112/89 if country==788 & cat_ville==1

/*Jordan*/
*2016
replace liv_wage=548*0.916431158 if round==2016
*2010
replace liv_wage=548*0.79350825  if round==2010

****Earn living wage****
gen earn_liv=.
replace earn_liv=1 if mnthwg>=liv_wage & mnthwg<.  & liv_wage!=.
replace earn_liv=0 if mnthwg<liv_wage & mnthwg<. & liv_wage!=.


****Poverty lines****
/*Jordan*/
*2016
/*same poverty line in 2010 for all Jordanian governorates*/
gen PL=68*5.1/1.5*1.1549 if round==2016
*1.5 workers per WageIndicator.org
*5.1 as typical family size 
**1.1549 ratio of prices 2010 to 2016

/*same poverty line in 2010 for all Jordanian governorates*/
replace PL=68*5.1/1.5  if round==2010
*1.5 workers per WageIndicator.org
*5.1 as typical family size 
*No deflation

/*Extreme poverty line */
*2016
gen EPL = 28*5.1/1.5*1.1549 if round==2016
*2010
replace EPL = 28*5.1/1.5 if round==2010

/*Tunisia*/
/*PL differs between large, small and medium and rural cities */
replace PL=112*4.5/1.46*(1-0.04437) if country==788 & cat_ville==1
replace PL=101*4.5/1.46*(1-0.04437) if country==788 & cat_ville==2
replace PL=89*4.5/1.46*(1-0.04437) if country==788 & cat_ville==3
*1.46 earners per household per Anker
*4.5 as household size
*4.437 as inflation from 2014 to 2015

/*Extreme poverty line */
replace EPL=64*4.5/1.46*(1-0.04437) if country==788 & cat_ville==1
replace EPL=62*4.5/1.46*(1-0.04437) if country==788 & cat_ville==2
replace EPL=57*4.5/1.46*(1-0.04437) if country==788 & cat_ville==3

****Earn the poverty line****
gen earn_PL=.
replace earn_PL=1 if mnthwg>=PL & mnthwg<.  & PL!=.
replace earn_PL=0 if mnthwg<PL & mnthwg<. & PL!=.

****Earn the extreme line****
gen earn_EPL=.
replace earn_EPL=1 if mnthwg>=EPL & mnthwg<.  & EPL!=.
replace earn_EPL=0 if mnthwg<EPL & mnthwg<. & EPL!=.


***Earn the median
gen earn_med=.
gen median=.
foreach num of numlist 2010 2014 2016 {
	sum mnthwg if round==`num' [aw=expan_ind], detail
	replace median=`r(p50)' if round==`num'
	replace earn_med=0 if round==`num' & mnthwg!=. & mnthwg<`r(p50)'
	replace earn_med=1 if round==`num' & mnthwg!=. & mnthwg>=`r(p50)'
}

*Check
tabu round earn_med [aw=expan_ind], row nofreq

***Earn unemployed 
egen avg_min=rowmean(min_priv_form min_priv_inf min_pub)

tabu avg_min round

*Earn minimum if worked (unemployed)
gen un_earn_min=.
replace un_earn_min=1 if unemp1==1 & avg_min>=un_minimum & avg_min<.  & un_minimum!=.
replace un_earn_min=0 if unemp1==1 & avg_min<un_minimum & avg_min<. & un_minimum!=.

tabu un_earn_min country [aw=expan_ind], col nofreq

*Earn living if worked (unemployed)
gen un_earn_liv=.
replace un_earn_liv=1 if unemp1==1 & avg_min>=liv_wage & avg_min<.  & liv_wage!=.
replace un_earn_liv=0 if unemp1==1 & avg_min<liv_wage & avg_min<. & liv_wage!=.

tabu un_earn_liv country [aw=expan_ind], col nofreq



*Earn poverty if worked (unemployed)
gen un_earn_PL=.
replace un_earn_PL=1 if unemp1==1 & avg_min>=PL & avg_min<.  & PL!=.
replace un_earn_PL=0 if unemp1==1 & avg_min<PL & avg_min<. & PL!=.

tabu un_earn_PL country [aw=expan_ind], col nofreq

*Earn median if worked (unemployed)
gen un_earn_med=.
replace un_earn_med=1 if unemp1==1 & avg_min>=median & avg_min<.  & median!=.
replace un_earn_med=0 if unemp1==1 & avg_min<median & avg_min<. & median!=.

tabu un_earn_med country [aw=expan_ind], col nofreq


****Wage gap from minimum*****
gen min_gap=minimum-mnthwg if earn_min==0
gen ln_min_gap=ln(min_gap) if earn_min==0



****Wage gap from living*****
gen liv_gap=liv_wage-mnthwg if earn_liv==0
gen ln_liv_gap=ln(liv_gap) if earn_liv==0



****Wage gap from poverty*****
gen PL_gap=PL-mnthwg if earn_PL==0
gen ln_PL_gap=ln(PL_gap) if earn_PL==0


****Wage gap from median*****
gen med_gap=median-mnthwg if earn_med==0
gen ln_med_gap=ln(med_gap) if earn_med==0




**********
*Covariates
***********

****Individual****

*Nationality 
fre nationality_cl

*Age group
fre agegrp2
recode agegrp2 (14/16=14)
la def Lagegrp2 14 "65+", modify

*Sex
fre sex

*Marital status
fre marital if mnthwg!=.
recode marital (3/4=2)

*Education
fre educ1d
recode educ1d (7=6)

*Work experience
/*for JLMPS 2010, we don't have the variable "exp", we have the variable "yrjob1" that indicates the year of the first job */
replace wexp=2010-yrjob1+1 if round==2010
tabu wexp

foreach num of numlist 2010 2014 2016 {
	sum wexp if round==`num' & usempstp==1
	replace wexp=`r(mean)' if round==`num' & usempstp==1 & wexp==.
}

*Social insurance
fre ussocinsp 

*Contract
fre uscontrp  
replace uscontrp=2 if uscontrdur==1

la def Luscontrdur 0 "No contract" 1 "Definite duration" 2 "Indefinite duration"
la val uscontrp Luscontrdur

*Regularity
fre usirreg 
la def Lusirreg 0 "Regular" 1 "Irregular"
la val usirreg Lusirreg

*Establishment
fre usestblp
la def Lusestblp 0 "Outside establishment" 1 "Inside establishment"

*Education requirement
*not available in JLMPS 2010
fre edreq 
recode edreq (7=6) (2=1)

*Skill requirement
fre skilreq

fre literacy math fitness computer
	la val literacy math fitness computer yesno

****Firm****

*Econ. act. 
fre usecac1d_cl
recode usecac1d_cl (2 3 4=1) (5=2) (6=3) (7=4) (8=5) (9/20=6)
replace usecac1d_cl=7 if usecac1d_cl==. & usemp1==1
label define Lecac 0 "Agriculture" 1 "Manufacturing & utilities" 2 "Construction"  ///
3 "Wholesale & retail" 4 "Transp. & storage" 5 "Accomm. & food serv." 6 "Other Services" 7 "Missing", modify
label val usecac1d_cl Lecac
fre usecac1d_cl

*Firm size
fre usfirm_size
recode usfirm_size (7=6)
la def Lfirm_size 6 "100+/don't know", modify

*% female
fre usfmwrkprcnt
replace usfmwrkprcnt=5 if usfmwrkprcnt==. & usemp1==1

*Public
gen uspublic=1 if ussectrp>=1 & ussectrp<=2
replace uspublic=0 if ussectrp>=3 & ussectrp<=5
fre uspublic

la var uspublic "Sector"
la def Luspublic 0 "Private" 1 "Public"
la val uspublic Luspublic


*Location
fre urban
fre region

****Job****

*Occupations
tabu usocp1d round if mnthwg!=.

*Combining managers with professionals
recode usocp1d (1=2)
la def ocp1digit 2 "Managers and professionals", modify

*Social insurance
fre ussocinsp
replace ussocinsp=2 if other_socins==1

la def Lussocinsp 0 "Uninsured in informal firm" 1 "Insured" 2 "Uninsured in a formal firm"
la val ussocinsp Lussocinsp

*Check
bysort round: sum agegrp2 sex marital educ1 wexp ///
usocp1d ussocinsp uscontrp usirreg usestblp edreq skilreq literacy math fitness computer ///
usecac1d usfirm_size usfmwrkprcnt uspublic urban mnthwg minimum if usempstp==1 & expan_indiv!=. & mnthwg!=. [aw=expan_indiv]

save "Wages JO TN analysis data.dta", replace
