/* 
Models
Ford Social Protection -- Living and Minimum Wages in Jordan and Tunisia
Created: November 8 2021
Updated: 2024.01.01
Last updated by: Caroline Krafft

Version 9

*/


*Analysis data
use "Wages JO TN analysis data.dta", clear


/*Covariates 
Age group: 15-19 reference
Sex: Female, male reference
Marital status: Single reference vs. (ever)ƒ married
Education (int. w/sex): Illiterate reference
Work experience and square (continuous)

Occupation: Prof./man. reference
Social insurance (none ref.)
Contract (none ref.)
Regular (irregular ref.)
In an establishment vs. out
Education requirements (no formal schooling omit.)
Skill required (none omit.)
Years on the job and square

Econ. act. (ag. omit)
Firm size (1-4 workers omit.)
% female (none omit.)
Public sector (private omit)
Region (capital omit)
Urban (rural omit.)

Nationality: Jordanian
*/

*All waves
global covs b4.agegrp2 b1.sex##b1.marital b1.sex##b1.educ1 c.wexp c.wexp#c.wexp b2.urban /*worker*/  ///
b2.usocp1d b0.ussocinsp b0.uscontrp  b1.usirreg b0.usestblp b0.skilreq /* job */ ///
b0.usecac1d b1.usfirm_size b0.uspublic /* firm */

*2016/2014 only
global add_covs b1.usfmwrkprcnt b2.literacy b2.math b2.fitness b2.computer b1.edreq

/* 
Outcome of earning a minimum wage
Presenting odds ratios
*/

*Tunisia
logit earn_min $covs $add_covs b7881.region  if country==788 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_min_788

*Jordan - 2010
logit earn_min $covs b4001.region  b1.nationality_cl if round==2010 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_min_2010

*Jordan - 2016
logit earn_min $covs $add_covs b4001.region  b1.nationality_cl if round==2016 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_min_2016



/* 
Outcome of earning a poverty wage
Presenting odds ratios
*/

*Jordan - 2010
logit earn_PL $covs b4001.region  b1.nationality_cl if round==2010 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_PL_2010

*Jordan - 2016 
logit earn_PL $covs $add_covs b4001.region  b1.nationality_cl if round==2016 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_PL_2016

*Tunisia
logit earn_PL $covs $add_covs b7881.region  if country==788 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_PL_788


/* 
Outcome of earning a median wage
Presenting odds ratios
*/

*Jordan - 2010
logit earn_med $covs b4001.region  b1.nationality_cl if round==2010 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_med_2010

*Jordan - 2016
logit earn_med $covs $add_covs b4001.region  b1.nationality_cl if round==2016 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_med_2016


*Tunisia
logit earn_med $covs $add_covs b7881.region  if country==788 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_med_788


/* 
Outcome of earning a living wage
Presenting odds ratios
*/

*Jordan - 2010
logit earn_liv $covs b4001.region  b1.nationality_cl if round==2010 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_liv_2010

*Jordan - 2016
logit earn_liv $covs $add_covs b4001.region  b1.nationality_cl if round==2016 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_liv_2016


*Tunisia
logit earn_liv $covs $add_covs b7881.region  if country==788 [pw=expan_indiv], cluster(Fpsu) or

estimates store earn_liv_788


******
*Table
******

esttab /*2010*/ earn_min_2010 earn_PL_2010 earn_med_2010 earn_liv_2010 /*2016*/ earn_min_2016 earn_PL_2016 earn_med_2016 earn_liv_2016 /* TN */ earn_min_788 earn_PL_788 earn_med_788 earn_liv_788 using "Graphs and Tables/Wages JO TN min model.csv", ///
 replace eform label cells(b(star fmt(%9.3f)) se(par)) ///
 noomit nobase order(*nationality_cl *agegrp2 2.sex *marital *educ1d *wexp *urban *region /*worker*/ *usocp1d *ussocinsp *uscontrp *usirreg *usestblp *edreq *skilreq *literacy *math *fitness *computer /* job */ *usecac1d_cl *usfirm_size *usfmwrkprcnt *uspublic /* firm */) ///
 stats(p N r2_p, fmt(%9.3f %9.0g)) mlabel("Jordan 2010 - min." "Jordan 2010 - pov." "Jordan 2010 - med." " Jordan 2010 - liv."  "Jordan 2016 - min." "Jordan 2016 - pov." "Jordan 2016 - med." " Jordan 2016 - liv." "Tunisia - min." "Tunisia - pov." "Tunisia - med." "Tunisia - liv.") refcat(5.agegrp2 "Age group (15-19 omit.)" 2.sex "Sex (male omit.)" 2.marital "Ever married (single omit.)" 2.sex#2.marital "Sex and ever married int." 2.educ1d "Education (illit. omit.)" 2.sex#2.educ1d "Sex and educ. int." wexp "Work experience" 3.usocp1d "Occupation (prof./man. omit.)" 1.ussocinsp "Social insurance (uninsured (in informal firm 2014/16) omit.)" 1.uscontrp "Contract (none omit.)" 0.usirreg "Regularity (irregular omit.)" 1.usestblp "Work in est. (outside omit.)"   3.edreq "Required education (none omit.)" 1.skilreq "Job req. tech skills (no omit.)" 1.literacy "Job req. lit. skill (no omit.)" 1.math "Job req. math skill (no omit.)" 1.fitness "Job req. fitness skill (no omit.)" 1.computer "Job req. computer skill (no omit.)" 1.usecac1d_cl "Industry (agric. omit.)"2.usfirm_size "Firm size (1-4 workers omit.)" 2.usfmwrkprcnt "% firm female (none omit.)" 1.uspublic "Firm sector (private omit.)" 1.urban "Urban (rural omit.)" 4002.region "Region (capitol omit.)" 2.nationality_cl "Nationality (Jor. omit)", nolabel) 
 

***********
*By sector - minimum 
***********
 

*Tunisia

/*private sector*/
logit earn_min $covs $add_covs b7881.region  if country==788 & uspublic==0 [pw=expan_indiv], cluster(Fpsu) or
estimates store earn_min_788priv

*Jordan - 2010

/*private sector*/
logit earn_min $covs b4001.region  b1.nationality_cl if round==2010 & uspublic==0 [pw=expan_indiv], cluster(Fpsu) or
estimates store earn_min_2010priv


*Jordan - 2016

/*private sector*/
logit earn_min $covs $add_covs b4001.region  b1.nationality_cl if round==2016 & uspublic==0 [pw=expan_indiv], cluster(Fpsu) or
estimates store earn_min_2016priv



******
*Table
******

esttab earn_min_2010priv earn_min_2016priv earn_min_788priv using "Graphs and Tables/Wages JO TN min model sector Analysis public private.csv", ///
 replace eform label cells(b(star fmt(%9.3f)) se(par)) ///
 stats(p N r2_p, fmt(%9.3f %9.0g)) noomit nobase order(*nationality_cl *agegrp2 2.sex *marital *educ1d *wexp *urban *region /*worker*/ *usocp1d *ussocinsp *uscontrp *usirreg *usestblp *edreq *skilreq *literacy *math *fitness *computer /* job */ *usecac1d_cl *usfirm_size *usfmwrkprcnt /* firm */) ///
 mlabel("Jordan 2010 - min. priv." "Jordan 2016 - min. priv." "Tunisia - min. priv.") refcat(5.agegrp2 "Age group (15-19 omit.)" 2.sex "Sex (male omit.)" 2.marital "Ever married (single omit.)" 2.sex#2.marital "Sex and ever married int." 2.educ1d "Education (illit. omit.)" 2.sex#2.educ1d "Sex and educ. int." wexp "Work experience" 3.usocp1d "Occupation (prof./man. omit.)" 1.ussocinsp "Social insurance (uninsured (in informal firm 2014/16) firm omit.)" 1.uscontrp "Contract (none omit.)" 0.usirreg "Regularity (irregular omit.)" 1.usestblp "Work in est. (outside omit.)"   3.edreq "Required education (none omit.)" 1.skilreq "Job req. tech skills (no omit.)"  1.literacy "Job req. lit. skill (no omit.)" 1.math "Job req. math skill (no omit.)" 1.fitness "Job req. fitness skill (no omit.)" 1.computer "Job req. computer skill (no omit.)" 1.usecac1d_cl "Industry (agric. omit.)"2.usfirm_size "Firm size (1-4 workers omit.)" 2.usfmwrkprcnt "% firm female (none omit.)" /*1.uspublic "Firm sector (private omit.)"*/ 1.urban "Urban (rural omit.)" 4002.region "Region (capitol omit.)" 2.nationality_cl "Nationality (Jor. omit)", nolabel) 
 
